@@ -843,6 +843,10 @@ class ServerManager(base.BootingManagerWithFind):
         :param marker: Begin returning servers that appear later in the server
                        list than that represented by this server id (optional).
         :param limit: Maximum number of servers to return (optional).
+                      Note the API server has a configurable default limit.
+                      If no limit is specified here or limit is larger than
+                      default, the default limit will be used.
+                      If limit == -1, all servers will be returned.
         :param sort_keys: List of sort keys
         :param sort_dirs: List of sort directions
 
@@ -862,9 +866,14 @@ class ServerManager(base.BootingManagerWithFind):
             search_opts = {}
 
         qparams = {}
-
+        # In microversion 2.73 we added ``locked`` filtering option
+        # for listing server details.
+        if ('locked' in search_opts and
+                self.api_version < api_versions.APIVersion('2.73')):
+            raise exceptions.UnsupportedAttribute("locked", "2.73")
         for opt, val in search_opts.items():
-            if val:
+            # support locked=False from 2.73 microversion
+            if val or (opt == 'locked' and val is False):
                 if isinstance(val, six.text_type):
                     val = val.encode('utf-8')
                 qparams[opt] = val
